From 0d069fcb262b0fb3d64adef5c534f783c10bb78a Mon Sep 17 00:00:00 2001
From: klemens <ka7@github.com>
Date: Tue, 28 Mar 2017 20:53:06 +0200
Subject: [PATCH] spelling fixes

---
 src/convert.c                      | 2 +-
 src/cookies.c                      | 4 ++--
 src/ftp.c                          | 6 +++---
 src/html-parse.c                   | 4 ++--
 src/init.c                         | 2 +-
 src/iri.c                          | 2 +-
 src/log.c                          | 2 +-
 src/mswindows.c                    | 2 +-
 src/progress.c                     | 2 +-
 src/recur.c                        | 4 ++--
 src/utils.c                        | 4 ++--
 testenv/README                     | 6 +++---
 testenv/Test-auth-basic.py         | 2 +-
 testenv/Test-auth-both.py          | 2 +-
 testenv/server/http/http_server.py | 6 +++---
 tests/Test-idn-meta.px             | 2 +-
 tests/WgetTests.pm                 | 2 +-
 vms/WGET.HLP                       | 2 +-
 18 files changed, 28 insertions(+), 28 deletions(-)

diff --git a/src/convert.c b/src/convert.c
index 509923e..78cbafb 100644
--- a/src/convert.c
+++ b/src/convert.c
@@ -1024,7 +1024,7 @@ convert_cleanup (void)
 
 /* This table should really be merged with dl_file_url_map and
    downloaded_html_files.  This was originally a list, but I changed
-   it to a hash table beause it was actually taking a lot of time to
+   it to a hash table because it was actually taking a lot of time to
    find things in it.  */
 
 static struct hash_table *downloaded_files_hash;
diff --git a/src/cookies.c b/src/cookies.c
index a250770..e316ea1 100644
--- a/src/cookies.c
+++ b/src/cookies.c
@@ -485,7 +485,7 @@ parse_set_cookie (const char *set_cookie, bool silent)
 /* Check whether ADDR matches <digits>.<digits>.<digits>.<digits>.
 
    We don't want to call network functions like inet_addr() because
-   all we need is a check, preferrably one that is small, fast, and
+   all we need is a check, preferably one that is small, fast, and
    well-defined.  */
 
 static bool
@@ -516,7 +516,7 @@ numeric_address_p (const char *addr)
    psl on our own, if libpsl is compiled without a public suffix list,
    fall back to using the original "tail matching" heuristic. Also if
    libpsl is unable to convert the domain to lowercase, which means that
-   it doesnt have any runtime conversion support, we again fall back to
+   it doesn't have any runtime conversion support, we again fall back to
    "tail matching" since libpsl states the results are unpredictable with
    upper case strings.
    */
diff --git a/src/init.c b/src/init.c
index 63c89b5..a3d64dc 100644
--- a/src/init.c
+++ b/src/init.c
@@ -578,7 +578,7 @@ wgetrc_env_file_name (void)
   return NULL;
 }
 
-/* Check for the existance of '$HOME/.wgetrc' and return its path
+/* Check for the existence of '$HOME/.wgetrc' and return its path
    if it exists and is set.  */
 char *
 wgetrc_user_file_name (void)
diff --git a/src/iri.c b/src/iri.c
index db87135..2a4da1d 100644
--- a/src/iri.c
+++ b/src/iri.c
@@ -255,7 +255,7 @@ idn_encode (const struct iri *i, const char *host)
   if (!i->utf8_encode)
     {
       if (!remote_to_utf8 (i, host, &utf8_encoded))
-          return NULL;  /* Nothing to encode or an error occured */
+          return NULL;  /* Nothing to encode or an error occurred */
       src = utf8_encoded;
     }
   else
diff --git a/src/log.c b/src/log.c
index 51f30c4..6f9b0c7 100644
--- a/src/log.c
+++ b/src/log.c
@@ -532,7 +532,7 @@ log_set_flush (bool flush)
     }
   else
     {
-      /* Reenable flushing.  If anything was printed in no-flush mode,
+      /* Re-enable flushing.  If anything was printed in no-flush mode,
          flush the log now.  */
       if (needs_flushing)
         logflush ();
diff --git a/src/mswindows.c b/src/mswindows.c
index 90e6ec4..f7e03bd 100644
--- a/src/mswindows.c
+++ b/src/mswindows.c
@@ -580,7 +580,7 @@ run_with_timeout (double seconds, void (*fun) (void *), void *arg)
 const char *
 inet_ntop (int af, const void *src, char *dst, socklen_t cnt)
 {
-  /* struct sockaddr can't accomodate struct sockaddr_in6. */
+  /* struct sockaddr can't accommodate struct sockaddr_in6. */
   union {
     struct sockaddr_in6 sin6;
     struct sockaddr_in sin;
diff --git a/src/progress.c b/src/progress.c
index f44e0ee..36037df 100644
--- a/src/progress.c
+++ b/src/progress.c
@@ -75,7 +75,7 @@ static struct progress_implementation implementations[] = {
 static struct progress_implementation *current_impl;
 static int current_impl_locked;
 
-/* Progress implementation used by default.  Can be overriden in
+/* Progress implementation used by default.  Can be overridden in
    wgetrc or by the fallback one.  */
 
 #define DEFAULT_PROGRESS_IMPLEMENTATION "bar"
diff --git a/src/recur.c b/src/recur.c
index 42b4eb1..1b25662 100644
--- a/src/recur.c
+++ b/src/recur.c
@@ -497,7 +497,7 @@ retrieve_tree (struct url *start_url_parsed, struct iri *pi)
 
       if (file
           && (opt.delete_after
-              || opt.spider /* opt.recursive is implicitely true */
+              || opt.spider /* opt.recursive is implicitly true */
               || !acceptable (file)))
         {
           /* Either --delete-after was specified, or we loaded this
@@ -698,7 +698,7 @@ download_child (const struct urlpos *upos, struct url *parent, int depth,
      for directories (no file name to match) and for non-leaf HTMLs,
      which can lead to other files that do need to be downloaded.  (-p
      automatically implies non-leaf because with -p we can, if
-     necesary, overstep the maximum depth to get the page requisites.)  */
+     necessary, overstep the maximum depth to get the page requisites.)  */
   if (u->file[0] != '\0'
       && !(has_html_suffix_p (u->file)
            /* The exception only applies to non-leaf HTMLs (but -p
diff --git a/src/utils.c b/src/utils.c
index 3acc78d..63ccd85 100644
--- a/src/utils.c
+++ b/src/utils.c
@@ -1736,7 +1736,7 @@ numdigit (wgint number)
 {
   int cnt = 1;
   if (number < 0)
-    ++cnt;                      /* accomodate '-' */
+    ++cnt;                      /* accommodate '-' */
   while ((number /= 10) != 0)
     ++cnt;
   return cnt;
@@ -2336,7 +2336,7 @@ wget_base64_encode (const void *data, size_t length, char *dest)
 
 /* Decode data from BASE64 (a null-terminated string) into memory
    pointed to by DEST.  DEST is assumed to be large enough to
-   accomodate the decoded data, which is guaranteed to be no more than
+   accommodate the decoded data, which is guaranteed to be no more than
    3/4*strlen(base64).
 
    Since DEST is assumed to contain binary data, it is not
diff --git a/testenv/README b/testenv/README
index 8ca80f2..6580bc9 100644
--- a/testenv/README
+++ b/testenv/README
@@ -4,7 +4,7 @@ Install Instructions:
 ================================================================================
 
 This Test Suite exploits the Parallel Test Harness available in GNU Autotools.
-Since it uses features from a relatively recent verion of Autotools, the minimum
+Since it uses features from a relatively recent version of Autotools, the minimum
 required version as been bumped up to 1.11.
 Run the './configure' command to generate the Makefile and then run 'make check'
 to execute the Test Suite. Use the '-j n' option with 'make check' to execute
@@ -122,7 +122,7 @@ This would be very helpful to future contributors.
 Each File in the Test must be represented as a WgetFile object. The WgetFile
 Class has the following prototype:
 WgetFile (str name, str contents, str timestamp, dict rules)
-None except name is a mandatory paramter, one may pass only those parameters
+None except name is a mandatory parameter, one may pass only those parameters
 that are required by the File object.
 
 The timestamp string should be in a format: "YYYY-MM-DD HH:MM:SS" in UTC zone.
@@ -288,7 +288,7 @@ Some amount of work still remains to be done.
     * Support parallel-wget branch
         * Support to spawn multiple servers is already in place. Need to handle
         multiple requests to a server simultaneously. Use THreading MixIn.
-    * SSL Tests. Use xyne's HTTPS server implemention
+    * SSL Tests. Use xyne's HTTPS server implementation
     * Complete support for FTP Tests
     * IRI Support. This shouldn't require much effort
 
diff --git a/testenv/Test-auth-basic.py b/testenv/Test-auth-basic.py
index b94faaa..eaead88 100755
--- a/testenv/Test-auth-basic.py
+++ b/testenv/Test-auth-basic.py
@@ -5,7 +5,7 @@ from misc.wget_file import WgetFile
 
 """
     This test ensures Wget's Basic Authorization Negotiation.
-    Also, we ensure that Wget saves the host after a successfull auth and
+    Also, we ensure that Wget saves the host after a successful auth and
     doesn't wait for a challenge the second time.
 """
 ############# File Definitions ###############################################
diff --git a/testenv/Test-auth-both.py b/testenv/Test-auth-both.py
index 5913a1a..6e5d712 100755
--- a/testenv/Test-auth-both.py
+++ b/testenv/Test-auth-both.py
@@ -5,7 +5,7 @@ from misc.wget_file import WgetFile
 
 """
     This test ensures Wget's Basic Authorization Negotiation.
-    Also, we ensure that Wget saves the host after a successfull auth and
+    Also, we ensure that Wget saves the host after a successful auth and
     doesn't wait for a challenge the second time.
 """
 ############# File Definitions ###############################################
diff --git a/testenv/server/http/http_server.py b/testenv/server/http/http_server.py
index b222df0..ffc80ed 100644
--- a/testenv/server/http/http_server.py
+++ b/testenv/server/http/http_server.py
@@ -63,7 +63,7 @@ class _Handler(BaseHTTPRequestHandler):
     request. For each HTTP Request Command that the server should be capable of
     responding to, there must exist a do_REQUESTNAME() method which details the
     steps in which such requests should be processed. The rest of the methods
-    in this class are auxilliary methods created to help in processing certain
+    in this class are auxiliary methods created to help in processing certain
     requests. """
 
     def get_rule_list(self, name):
@@ -98,7 +98,7 @@ class _Handler(BaseHTTPRequestHandler):
         resource. Hence, we call the handle for processing PUT requests if the
         resource requested does not already exist.
 
-        Currently, when the server recieves a POST request for a resource, we
+        Currently, when the server receives a POST request for a resource, we
         simply append the body data to the existing file and return the new
         file to the client. If the file does not exist, a new file is created
         using the contents of the request body. """
@@ -377,7 +377,7 @@ class _Handler(BaseHTTPRequestHandler):
 
     def send_head(self, method):
         """ Common code for GET and HEAD Commands.
-        This method is overriden to use the fileSys dict.
+        This method is overridden to use the fileSys dict.
 
         The method variable contains whether this was a HEAD or a GET Request.
         According to RFC 2616, the server should not differentiate between
diff --git a/tests/Test-idn-meta.px b/tests/Test-idn-meta.px
index fd7dcfa..da9045e 100755
--- a/tests/Test-idn-meta.px
+++ b/tests/Test-idn-meta.px
@@ -27,7 +27,7 @@ my %urls = (
         code => "200",
         msg => "You want fries with that?",
         headers => {
-            # HTTP header preceeds http-equiv, simply just omit it here
+            # HTTP header preceds http-equiv, simply just omit it here
             #'Content-Type' => 'text/html; charset=UTF-8',
         },
         content => $starter_file,
diff --git a/tests/WgetTests.pm b/tests/WgetTests.pm
index 8236fbe..9207b4a 100644
--- a/tests/WgetTests.pm
+++ b/tests/WgetTests.pm
@@ -152,7 +152,7 @@ sub run
     $errcode >>= 8;    # XXX: should handle abnormal error codes.
 
     # Shutdown server
-    # if we didn't explicitely kill the server, we would have to call
+    # if we didn't explicitly kill the server, we would have to call
     # waitpid ($pid, 0) here in order to wait for the child process to
     # terminate
     kill 'TERM', $pid;
diff --git a/vms/WGET.HLP b/vms/WGET.HLP
index 88a854b..22e7373 100644
--- a/vms/WGET.HLP
+++ b/vms/WGET.HLP
@@ -240,7 +240,7 @@
  RMS parameter values by default: BLOCK_COUNT = 127, BUFFER_COUNT = 2,
  EXTEND_QUANTITY = 16384.
 
- The user may overide these values by specifying different (non-zero)
+ The user may override these values by specifying different (non-zero)
  values for these parameters using the SET RMS_DEFAULT command.
 
 3 File_attributes
diff --git a/src/ftp.c b/src/ftp.c
index a790c39..30f71eb 100644
--- a/src/ftp.c
+++ b/src/ftp.c
@@ -2070,7 +2070,7 @@ ftp_loop_internal (struct url *u, struct url *original_url, struct fileinfo *f,
         /* This is a directory listing file. */
         {
           if (!opt.remove_listing)
             /* --dont-remove-listing was specified, so do count this towards the
                number of bytes and files downloaded. */
             {
               total_downloaded_bytes += qtyread;
@@ -2078,7 +2078,7 @@ ftp_loop_internal (struct url *u, struct url *original_url, struct fileinfo *f,
             }
 
           /* Deletion of listing files is not controlled by --delete-after, but
-             by the more specific option --dont-remove-listing, and the code
+             by the more specific option --don't-remove-listing, and the code
              to do this deletion is in another function. */
         }
       else if (!opt.spider)
@@ -2129,7 +2129,7 @@ Removing file due to --delete-after in ftp_loop_internal():\n"));
 }
 
 /* Return the directory listing in a reusable format.  The directory
-   is specifed in u->dir.  */
+   is specified in u->dir.  */
 static uerr_t
 ftp_get_listing (struct url *u, struct url *original_url, ccon *con,
                  struct fileinfo **f)
@@ -2070,7 +2070,7 @@ ftp_loop_internal (struct url *u, struct url *original_url, struct fileinfo *f,
         {
           if (!opt.remove_listing)
-            /* --dont-remove-listing was specified, so do count this towards the
+            /* --don't-remove-listing was specified, so do count this towards the
                number of bytes and files downloaded. */
             {
diff --git a/src/html-parse.c b/src/html-parse.c
index ae436d0..c14d73a 100644
--- a/src/html-parse.c
+++ b/src/html-parse.c
@@ -176,8 +176,8 @@ struct pool {
   P->orig_size = P->size;                                       \
 } while (0)
 
-/* Grow the pool to accomodate at least SIZE new bytes.  If the pool
-   already has room to accomodate SIZE bytes of data, this is a no-op.  */
+/* Grow the pool to accommodate at least SIZE new bytes.  If the pool
+   already has room to accommodate SIZE bytes of data, this is a no-op.  */
 
 #define POOL_GROW(p, increase)                                  \
   GROW_ARRAY ((p)->contents, (p)->size, (p)->tail + (increase), \
-- 
2.1.4

